=====
GOUDA
=====


Good Old Utilities for Data Analysis


Description
===========

These are a bunch of miscellaneous data/image utilities that have been made as needed. Full documentation on its way.


Note
====

This project has been set up using PyScaffold 3.2.1. For details and usage
information on PyScaffold see https://pyscaffold.org/.
